@@ -32,7 +32,7 @@ class OpenAPILoader(BaseLoader):
         file_path = content
         data_content = []
         with OpenAPILoader._get_file_content(content=content) as file:
-            yaml_data = yaml.load(file, Loader=yaml.Loader)
+            yaml_data = yaml.load(file, Loader=yaml.SafeLoader)
             for i, (key, value) in enumerate(yaml_data.items()):
                 string_data = f"{key}: {value}"
                 meta_data = {"url": file_path, "row": i + 1}
