@@ -21,8 +21,11 @@ class WebPageLoader(BaseLoader):
     _session = requests.Session()
 
     def load_data(self, url):
-        """Load data from a web page using a shared requests session."""
-        response = self._session.get(url, timeout=30)
+        """Load data from a web page using a shared requests' session."""
+        headers = {
+            "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/98.0.4758.102 Safari/537.36",  # noqa:E501
+        }
+        response = self._session.get(url, headers=headers, timeout=30)
         response.raise_for_status()
         data = response.content
         content = self._get_clean_content(data, url)
@@ -40,7 +43,8 @@ class WebPageLoader(BaseLoader):
             ],
         }
 
-    def _get_clean_content(self, html, url) -> str:
+    @staticmethod
+    def _get_clean_content(html, url) -> str:
         soup = BeautifulSoup(html, "html.parser")
         original_size = len(str(soup.get_text()))
 
@@ -60,8 +64,8 @@ class WebPageLoader(BaseLoader):
             tag.decompose()
 
         ids_to_exclude = ["sidebar", "main-navigation", "menu-main-menu"]
-        for id in ids_to_exclude:
-            tags = soup.find_all(id=id)
+        for id_ in ids_to_exclude:
+            tags = soup.find_all(id=id_)
             for tag in tags:
                 tag.decompose()
 
